@@ -3,9 +3,8 @@ var context_8h =
     [ "zyppng::Context", "classzyppng_1_1Context.html", "classzyppng_1_1Context" ],
     [ "zyppng::KeyRing", "namespacezyppng.html#a2c0f79ed9e5fb75b7e04c0ac651f06dd", null ],
     [ "zyppng::KeyRingRef", "namespacezyppng.html#a5871ccc48bf67277d35c18493fbada8f", null ],
+    [ "zyppng::MaybeAsyncContextRef", "namespacezyppng.html#ad518718c7ec808263d1d6d4f1c9d4646", null ],
     [ "zypp::DEFINE_PTR_TYPE", "namespacezypp.html#a6daf6de2371ba670de6df270dd0aa1d4", null ],
     [ "zyppng::ZYPP_FWD_DECL_TYPE_WITH_REFS", "namespacezyppng.html#a4a691bbc0e77b43fc6c124a696e28a39", null ],
-    [ "zyppng::ZYPP_FWD_DECL_TYPE_WITH_REFS", "namespacezyppng.html#a0c94b8ba06a0f259bd58494cb843c230", null ],
-    [ "zyppng::ZYPP_FWD_DECL_TYPE_WITH_REFS", "namespacezyppng.html#acbdf69bf0b3d82251902af4d7f451545", null ],
-    [ "zyppng::joinPipeline", "namespacezyppng.html#a907fea3082b860e673845901f21f7e10", null ]
+    [ "zyppng::joinPipeline", "namespacezyppng.html#acd69cb6cb5ea3390e8e0cd1caa8de307", null ]
 ];
\ No newline at end of file
