@@ -20,8 +20,6 @@ var functions_eval =
     [ "s", "functions_eval_s.html", null ],
     [ "t", "functions_eval_t.html", null ],
     [ "u", "functions_eval_u.html", null ],
-    [ "v", "functions_eval_v.html", null ],
     [ "w", "functions_eval_w.html", null ],
-    [ "y", "functions_eval_y.html", null ],
-    [ "z", "functions_eval_z.html", null ]
+    [ "y", "functions_eval_y.html", null ]
 ];
\ No newline at end of file
