@@ -11,7 +11,6 @@ var namespacemembers_func =
     [ "h", "namespacemembers_func_h.html", null ],
     [ "i", "namespacemembers_func_i.html", null ],
     [ "j", "namespacemembers_func_j.html", null ],
-    [ "k", "namespacemembers_func_k.html", null ],
     [ "l", "namespacemembers_func_l.html", null ],
     [ "m", "namespacemembers_func_m.html", null ],
     [ "n", "namespacemembers_func_n.html", null ],
@@ -25,6 +24,5 @@ var namespacemembers_func =
     [ "v", "namespacemembers_func_v.html", null ],
     [ "w", "namespacemembers_func_w.html", null ],
     [ "x", "namespacemembers_func_x.html", null ],
-    [ "z", "namespacemembers_func_z.html", null ],
-    [ "~", "namespacemembers_func_~.html", null ]
+    [ "z", "namespacemembers_func_z.html", null ]
 ];
\ No newline at end of file
