@@ -4,15 +4,12 @@ var namespacezypp_1_1media =
     [ "AttachPoint", "classzypp_1_1media_1_1AttachPoint.html", "classzypp_1_1media_1_1AttachPoint" ],
     [ "AuthData", "classzypp_1_1media_1_1AuthData.html", "classzypp_1_1media_1_1AuthData" ],
     [ "AuthDataComparator", "structzypp_1_1media_1_1AuthDataComparator.html", "structzypp_1_1media_1_1AuthDataComparator" ],
-    [ "AuthenticationReport", "structzypp_1_1media_1_1AuthenticationReport.html", "structzypp_1_1media_1_1AuthenticationReport" ],
     [ "CDTools", "classzypp_1_1media_1_1CDTools.html", "classzypp_1_1media_1_1CDTools" ],
-    [ "CommitPreloadReport", "structzypp_1_1media_1_1CommitPreloadReport.html", "structzypp_1_1media_1_1CommitPreloadReport" ],
     [ "CredentialFileReader", "classzypp_1_1media_1_1CredentialFileReader.html", "classzypp_1_1media_1_1CredentialFileReader" ],
     [ "CredentialManager", "classzypp_1_1media_1_1CredentialManager.html", "classzypp_1_1media_1_1CredentialManager" ],
     [ "CredManagerOptions", "structzypp_1_1media_1_1CredManagerOptions.html", "structzypp_1_1media_1_1CredManagerOptions" ],
     [ "CurlAuthData", "classzypp_1_1media_1_1CurlAuthData.html", "classzypp_1_1media_1_1CurlAuthData" ],
     [ "CurlConfig", "structzypp_1_1media_1_1CurlConfig.html", "structzypp_1_1media_1_1CurlConfig" ],
-    [ "DownloadProgressReport", "structzypp_1_1media_1_1DownloadProgressReport.html", "structzypp_1_1media_1_1DownloadProgressReport" ],
     [ "MediaBadAttachPointException", "classzypp_1_1media_1_1MediaBadAttachPointException.html", "classzypp_1_1media_1_1MediaBadAttachPointException" ],
     [ "MediaBadCAException", "classzypp_1_1media_1_1MediaBadCAException.html", "classzypp_1_1media_1_1MediaBadCAException" ],
     [ "MediaBadFilenameException", "classzypp_1_1media_1_1MediaBadFilenameException.html", "classzypp_1_1media_1_1MediaBadFilenameException" ],
@@ -23,7 +20,6 @@ var namespacezypp_1_1media =
     [ "MediaBlock", "structzypp_1_1media_1_1MediaBlock.html", "structzypp_1_1media_1_1MediaBlock" ],
     [ "MediaBlockList", "classzypp_1_1media_1_1MediaBlockList.html", "classzypp_1_1media_1_1MediaBlockList" ],
     [ "MediaCD", "classzypp_1_1media_1_1MediaCD.html", "classzypp_1_1media_1_1MediaCD" ],
-    [ "MediaChangeReport", "structzypp_1_1media_1_1MediaChangeReport.html", "structzypp_1_1media_1_1MediaChangeReport" ],
     [ "MediaCIFS", "classzypp_1_1media_1_1MediaCIFS.html", "classzypp_1_1media_1_1MediaCIFS" ],
     [ "MediaCurl", "classzypp_1_1media_1_1MediaCurl.html", "classzypp_1_1media_1_1MediaCurl" ],
     [ "MediaCurl2", "classzypp_1_1media_1_1MediaCurl2.html", "classzypp_1_1media_1_1MediaCurl2" ],
@@ -75,7 +71,6 @@ var namespacezypp_1_1media =
     [ "ProxyInfo", "classzypp_1_1media_1_1ProxyInfo.html", "classzypp_1_1media_1_1ProxyInfo" ],
     [ "ProxyInfoLibproxy", "classzypp_1_1media_1_1ProxyInfoLibproxy.html", "classzypp_1_1media_1_1ProxyInfoLibproxy" ],
     [ "ProxyInfoSysconfig", "classzypp_1_1media_1_1ProxyInfoSysconfig.html", "classzypp_1_1media_1_1ProxyInfoSysconfig" ],
-    [ "ScopedDisableMediaChangeReport", "structzypp_1_1media_1_1ScopedDisableMediaChangeReport.html", "structzypp_1_1media_1_1ScopedDisableMediaChangeReport" ],
     [ "TmpUnsetEnv", "structzypp_1_1media_1_1TmpUnsetEnv.html", "structzypp_1_1media_1_1TmpUnsetEnv" ],
     [ "TransferSettings", "classzypp_1_1media_1_1TransferSettings.html", "classzypp_1_1media_1_1TransferSettings" ],
     [ "transition", "structzypp_1_1media_1_1transition.html", "structzypp_1_1media_1_1transition" ],
