@@ -1,9 +1,9 @@
 var provide_8h =
 [
     [ "zyppng::ProvideMediaHandle", "classzyppng_1_1ProvideMediaHandle.html", "classzyppng_1_1ProvideMediaHandle" ],
-    [ "zyppng::ProvideStatus", "classzyppng_1_1ProvideStatus.html", "classzyppng_1_1ProvideStatus" ],
-    [ "zyppng::ProvideStatus::Stats", "structzyppng_1_1ProvideStatus_1_1Stats.html", "structzyppng_1_1ProvideStatus_1_1Stats" ],
+    [ "zyppng::ProvideRes", "classzyppng_1_1ProvideRes.html", "classzyppng_1_1ProvideRes" ],
     [ "zyppng::Provide", "classzyppng_1_1Provide.html", "classzyppng_1_1Provide" ],
-    [ "zyppng::AnyMap", "namespacezyppng.html#ac51810204363e7f002f8d862a68bcc7a", null ],
+    [ "zyppng::ProvideRes", "namespacezyppng.html#a55f31a4167259de7ead99e792e9eaa12", null ],
+    [ "zyppng::ZYPP_FWD_DECL_TYPE_WITH_REFS", "namespacezyppng.html#acbdf69bf0b3d82251902af4d7f451545", null ],
     [ "zyppng::DEFINE_PTR_TYPE", "namespacezyppng.html#af29d499dfa74208b46d53354674f16e9", null ]
 ];
\ No newline at end of file
