@@ -1,6 +1,5 @@
 var structzyppng_1_1detail_1_1collect__transitions__helper_3_01State_00_01TupleSoFar_00_01Head_01_4 =
 [
     [ "Type", "structzyppng_1_1detail_1_1collect__transitions__helper_3_01State_00_01TupleSoFar_00_01Head_01_4.html#a1108b87c5f5943c46f544ba069184641", null ],
-    [ "NewTuple", "structzyppng_1_1detail_1_1collect__transitions__helper.html#ad214351a34007ab9c27b670ae2465388", null ],
-    [ "Type", "structzyppng_1_1detail_1_1collect__transitions__helper.html#adbc92d9717b39a3401869e7c8006d95b", null ]
+    [ "NewTuple", "structzyppng_1_1detail_1_1collect__transitions__helper.html#ad214351a34007ab9c27b670ae2465388", null ]
 ];
\ No newline at end of file
